@@ -1,7 +1,6 @@
 if (requireNamespace("testthat", quietly = TRUE)) {
-  library(testthat)
-  library(checkmate)
-  library(mlr3tuning)
-  
+  library("testthat")
+  library("checkmate")
+  library("mlr3tuning")
   test_check("mlr3tuning")
 }
