@@ -5,13 +5,12 @@ test_that("early stopping callback works", {
   library(mlr3pipelines) # nolint
 
   instance = tune(
-    method = "random_search",
+    tuner = tnr("random_search", batch_size = 1),
     task = tsk("pima"),
     learner = lrn("classif.xgboost", eta = to_tune(1e-04, 1e-1, logscale = TRUE), early_stopping_rounds = 20, nrounds = 1000, early_stopping_set = "test"),
     resampling = rsmp("cv", folds = 3),
     measures = msr("classif.ce"),
     term_evals = 2,
-    batch_size = 1,
     callbacks = clbk("mlr3tuning.early_stopping")
   )
 
@@ -21,12 +20,11 @@ test_that("early stopping callback works", {
   expect_null(instance$result_learner_param_vals$early_stopping_rounds)
 
   at = auto_tuner(
-    method = "random_search",
+    tuner = tnr("random_search", batch_size = 1),
     learner = lrn("classif.xgboost", eta = to_tune(1e-04, 1e-1, logscale = TRUE), early_stopping_rounds = 20, nrounds = 1000, early_stopping_set = "test"),
     resampling = rsmp("cv", folds = 3),
     measure = msr("classif.ce"),
     term_evals = 2,
-    batch_size = 1,
     callbacks = clbk("mlr3tuning.early_stopping")
   )
   at$train(tsk("pima"))
@@ -37,13 +35,12 @@ test_that("early stopping callback works", {
   expect_null(at$learner$param_set$values$early_stopping_rounds)
 
   expect_error(tune(
-    method = "random_search",
+    tuner = tnr("random_search",  batch_size = 5),
     task = tsk("pima"),
     learner = lrn("classif.rpart", cp = to_tune(1e-04, 1e-1, logscale = TRUE)),
     resampling = rsmp("cv", folds = 3),
     measures = msr("classif.ce"),
     term_evals = 10,
-    batch_size = 5,
     callbacks = clbk("mlr3tuning.early_stopping")
   ), "incompatible")
 })
@@ -52,13 +49,12 @@ test_that("backup callback works", {
   file = tempfile(fileext = ".rds")
 
   instance = tune(
-    method = tnr("random_search"),
+    tuner =  tnr("random_search", batch_size = 2),
     task = tsk("pima"),
     learner = lrn("classif.rpart", cp = to_tune(1e-04, 1e-1, logscale = TRUE)),
     resampling = rsmp("cv", folds = 3),
     measures = msr("classif.ce"),
     term_evals = 4,
-    batch_size = 2,
     callbacks = clbk("mlr3tuning.backup", path = file)
   )
 
@@ -70,13 +66,12 @@ test_that("backup callback works with standalone tuner", {
   file = tempfile(fileext = ".rds")
 
   instance = tune(
-    method = tnr("grid_search"),
+    tuner =  tnr("grid_search", batch_size = 2),
     task = tsk("pima"),
     learner = lrn("classif.rpart", cp = to_tune(1e-04, 1e-1, logscale = TRUE)),
     resampling = rsmp("cv", folds = 3),
     measures = msr("classif.ce"),
     term_evals = 4,
-    batch_size = 2,
     callbacks = clbk("mlr3tuning.backup", path = file)
   )
 
